@@ -43,7 +43,7 @@ export class WorldModel {
           this,
           robot.x,
           robot.y,
-          robot._orientation,
+          robot.orientation,
           robot.image
         )
     );
