@@ -7,6 +7,8 @@
 from ipywidgets import DOMWidget
 from traitlets import Unicode
 from ._frontend import module_name, module_version
+from IPython.display import HTML as html_print
+from IPython.display import display
 
 import time as _time
 from datetime import datetime
@@ -17,6 +19,14 @@ import json
 from .models import WorldModel, RobotModel
 from .robot import Robot
 
+def cstr(s, color='black'):
+    return "<div style='background:#FFFFC8;padding: 10px'> <text style=color:{}>{}</text></div>".format(color, s)
+
+def print_desc(msg, color="black"):
+    if msg is not None:
+        display(html_print(cstr(msg, color=color))) 
+
+
 
 class Maze(DOMWidget):
     """TODO: Add docstring here
@@ -37,23 +47,16 @@ class Maze(DOMWidget):
         cb = datetime.now().strftime('%f')
         self.current_call = json.dumps({'method_name': method_name, 'params': params, 'cb': cb})
     
-    def __init__(self, kwargs):
+    def __init__(self, model):
         super(Maze, self).__init__()
-        self.options = kwargs
-        self.model = WorldModel(self, kwargs)
+        self.model = model
         self.robots = [Robot(idx, x, self) for idx, x in enumerate(self.model.robots)]
-
-
+        print_desc(self.model.description)
+        
         display(self)
         _time.sleep(1)
 
-        self.js_call('draw_all', [
-            self.model.rows, 
-            self.model.cols, 
-            self.model.walls,
-            self.options.get("robots", []),
-            self.model.objects
-        ])
+        self.model.render_all(self.js_call)
     
     def bot(self, bot_index=0):
         return self.robots[bot_index]
@@ -64,5 +67,6 @@ class Maze(DOMWidget):
             self.js_call('msg', ['Task Completed'])
         else:
             self.js_call('error', ["One Or More Goal are Not Completed."])
-        return val
+        return val    
+
 
